@@ -16,6 +16,7 @@
  */
 
 #include <glib/gi18n.h>
+#include <libgd/gd.h>
 
 #include "bjb-bijiben.h"
 #include "bjb-color-button.h"
@@ -47,6 +48,7 @@ struct _BjbMainToolbarPrivate
   BjbMainView      *parent;
   BjbController    *controller;
   GtkWindow        *window;
+  GtkWidget        *back;
 
   /* Main View */
   GtkWidget        *new;
@@ -54,6 +56,8 @@ struct _BjbMainToolbarPrivate
   GtkWidget        *grid;
   GtkWidget        *select;
   GtkWidget        *search;
+  GtkWidget        *separator;
+  GtkWidget        *close;
   gulong            finish_sig;
   gulong            update_selection;
   gulong            search_handler;
@@ -62,7 +66,9 @@ struct _BjbMainToolbarPrivate
 
   /* When note view */
   BijiNoteObj      *note;
+  GtkWidget        *color;
   GtkWidget        *share;
+  GtkWidget        *menu;
   gulong            note_renamed;
   gulong            note_color_changed;
   GtkAccelGroup    *accel;
@@ -81,7 +87,24 @@ static GParamSpec *properties[NUM_PROPERTIES] = { NULL, };
 
 #define BJB_MAIN_TOOLBAR_GET_PRIVATE(o)  (G_TYPE_INSTANCE_GET_PRIVATE ((o), BJB_TYPE_MAIN_TOOLBAR, BjbMainToolbarPrivate))
 
-G_DEFINE_TYPE (BjbMainToolbar, bjb_main_toolbar, GD_TYPE_MAIN_TOOLBAR);
+G_DEFINE_TYPE (BjbMainToolbar, bjb_main_toolbar, GTK_TYPE_HEADER_BAR);
+
+
+static void
+bjb_main_toolbar_clear (BjbMainToolbar *self)
+{
+  g_clear_pointer (&self->priv->back     ,gtk_widget_destroy);
+  g_clear_pointer (&self->priv->color    ,gtk_widget_destroy);
+  g_clear_pointer (&self->priv->grid     ,gtk_widget_destroy);
+  g_clear_pointer (&self->priv->list     ,gtk_widget_destroy);
+  g_clear_pointer (&self->priv->menu     ,gtk_widget_destroy);
+  g_clear_pointer (&self->priv->new      ,gtk_widget_destroy);
+  g_clear_pointer (&self->priv->search   ,gtk_widget_destroy);
+  g_clear_pointer (&self->priv->select   ,gtk_widget_destroy);
+  g_clear_pointer (&self->priv->share    ,gtk_widget_destroy);
+  g_clear_pointer (&self->priv->separator,gtk_widget_destroy);
+  g_clear_pointer (&self->priv->close    ,gtk_widget_destroy);
+}
 
 /* Callbacks */
 
@@ -117,7 +140,9 @@ update_selection_label (BjbMainToolbar *self)
   else
     label = g_strdup_printf (g_dngettext (GETTEXT_PACKAGE, "%d selected", "%d selected", length),length);
 
-  gd_main_toolbar_set_labels (GD_MAIN_TOOLBAR (self), NULL, label);
+
+  gtk_header_bar_set_title (GTK_HEADER_BAR (self), NULL);
+  gtk_header_bar_set_subtitle (GTK_HEADER_BAR (self), label);
   g_free (label);
 
   return TRUE;
@@ -218,16 +243,27 @@ on_search_button_clicked (BjbMainToolbarPrivate *priv)
   bjb_window_base_set_show_search_bar (BJB_WINDOW_BASE (priv->window), show_bar);
 }
 
+static void
+on_close_clicked (GtkButton *button,
+                  gpointer   user_data)
+{
+  gtk_widget_destroy (GTK_WIDGET (BJB_MAIN_TOOLBAR (user_data)->priv->window));
+}
+
 static void
 add_search_button (BjbMainToolbar *self)
 {
   BjbMainToolbarPrivate *priv = self->priv;
+  GtkWidget *search_image;
   gboolean active;
 
-  priv->search = gd_main_toolbar_add_toggle (GD_MAIN_TOOLBAR (self),
-                                             "edit-find-symbolic",
-                                             NULL,
-                                             FALSE);
+  priv->search = gtk_toggle_button_new ();
+  search_image = gtk_image_new_from_icon_name ("edit-find-symbolic", GTK_ICON_SIZE_MENU);
+  gtk_button_set_image (GTK_BUTTON (priv->search), search_image);
+  gtk_widget_set_valign (priv->search, GTK_ALIGN_CENTER);
+  gtk_style_context_add_class (gtk_widget_get_style_context (priv->search),
+                               "image-button");
+  gtk_header_bar_pack_end (GTK_HEADER_BAR (self), priv->search);
   gtk_widget_set_tooltip_text (priv->search,
                                _("Search note titles, content and collections"));
 
@@ -238,6 +274,29 @@ add_search_button (BjbMainToolbar *self)
                             G_CALLBACK (on_search_button_clicked), priv);
 }
 
+static void
+add_close_button (BjbMainToolbar *self)
+{
+  BjbMainToolbarPrivate *priv = self->priv;
+  GtkWidget *close_image;
+
+  /* Close button */
+  priv->separator = gtk_separator_new (GTK_ORIENTATION_VERTICAL);
+  gtk_widget_set_valign (priv->separator, GTK_ALIGN_FILL);
+  gtk_header_bar_pack_end (GTK_HEADER_BAR (self), priv->separator);
+
+  priv->close = gtk_button_new ();
+  gtk_button_set_relief (GTK_BUTTON (priv->close), GTK_RELIEF_NONE);
+  close_image = gtk_image_new_from_icon_name ("window-close-symbolic", GTK_ICON_SIZE_MENU);
+  gtk_button_set_image (GTK_BUTTON (priv->close), close_image);
+  gtk_widget_set_valign (priv->close, GTK_ALIGN_CENTER);
+  gtk_style_context_add_class (gtk_widget_get_style_context (priv->close),
+                               "image-button");
+  gtk_header_bar_pack_end (GTK_HEADER_BAR (self), priv->close);
+  g_signal_connect (priv->close,"clicked",
+                    G_CALLBACK(on_close_clicked), self);
+}
+
 
 static void
 update_selection_buttons (BjbController *controller,
@@ -265,8 +324,12 @@ populate_bar_for_selection (BjbMainToolbar *self)
   add_search_button (self);
 
   /* Select */
-  priv->select = gd_main_toolbar_add_button (GD_MAIN_TOOLBAR (self),
-                                             NULL, _("Done"), FALSE);
+  priv->select = gtk_button_new_with_mnemonic (_("Done"));
+  gtk_widget_set_valign (priv->select, GTK_ALIGN_CENTER);
+  gtk_style_context_add_class (gtk_widget_get_style_context (priv->select),
+                               "text-button");
+  gtk_header_bar_pack_end (GTK_HEADER_BAR (self), priv->select);
+
   gtk_widget_set_tooltip_text (priv->select, _("Exit selection mode"));
   context = gtk_widget_get_style_context (priv->select);
   gtk_style_context_add_class (context, "suggested-action");
@@ -304,7 +367,9 @@ update_label_for_standard (BjbMainToolbar *self)
   else
     label = g_strdup (_("New and Recent"));
 
-  gd_main_toolbar_set_labels (GD_MAIN_TOOLBAR (self), label, NULL);
+
+  gtk_header_bar_set_title (GTK_HEADER_BAR (self), label);
+  gtk_header_bar_set_subtitle (GTK_HEADER_BAR (self), NULL);
   g_free (label);
 
   self->priv->display_notes = g_signal_connect (self->priv->controller,
@@ -338,6 +403,11 @@ populate_bar_for_standard(BjbMainToolbar *self)
   BjbMainToolbarPrivate *priv = self->priv;
   GtkWidget *bin = NULL;
   BijiCollection *coll;
+  GtkWidget *grid, *notes_icon, *notes_label;
+  GtkWidget *select_image;
+  gboolean rtl;
+
+  rtl = (gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL);
 
   /* Label */
   update_label_for_standard (self);
@@ -349,23 +419,31 @@ populate_bar_for_standard(BjbMainToolbar *self)
 
   if (coll)
   {
-    GtkWidget *back, *button;
+    grid = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
+    notes_icon = get_icon (rtl ? "go-previous-rtl-symbolic" : "go-previous-symbolic");
+    gtk_box_pack_start (GTK_BOX (grid), notes_icon, TRUE, TRUE, TRUE);
 
-    back = get_icon ("go-previous-symbolic");
-    button = gd_main_toolbar_add_button (GD_MAIN_TOOLBAR (self), NULL, NULL, TRUE);
-    gtk_container_add (GTK_CONTAINER (button), back);
+    notes_label = gtk_label_new (_("Notes"));
+    gtk_box_pack_start (GTK_BOX (grid), notes_label, TRUE, TRUE, TRUE);
+    priv->back = gtk_button_new ();
+    gtk_widget_set_valign (priv->back, GTK_ALIGN_CENTER);
+    gtk_style_context_add_class (gtk_widget_get_style_context (priv->back),
+                                 "text-button");
+    gtk_container_add (GTK_CONTAINER (priv->back), grid);
+    gtk_header_bar_pack_start (GTK_HEADER_BAR (self), priv->back);
 
-    g_signal_connect_swapped (button, "clicked",
+    g_signal_connect_swapped (priv->back, "clicked",
                               G_CALLBACK (on_back_button_clicked), self);
   }
 
   /* New Note button */
   else
   {
-    priv->new = gd_main_toolbar_add_button(GD_MAIN_TOOLBAR (self),
-                                           NULL,
-                                           _("New"),
-                                           TRUE);
+    priv->new = gtk_button_new_with_label (_("New"));
+    gtk_widget_set_valign (priv->new, GTK_ALIGN_CENTER);
+    gtk_style_context_add_class (gtk_widget_get_style_context (priv->new),
+                                 "text-button");
+    gtk_header_bar_pack_start (GTK_HEADER_BAR (self), priv->new);
     gtk_widget_set_size_request (priv->new, 70, -1);
     bin = gtk_bin_get_child (GTK_BIN (priv->new));
 
@@ -381,15 +459,21 @@ populate_bar_for_standard(BjbMainToolbar *self)
   }
 
   /* Go to selection mode */
-  priv->select = gd_main_toolbar_add_button(GD_MAIN_TOOLBAR (self),
-                                            "object-select-symbolic",
-                                            NULL,
-                                            FALSE);
+  priv->select = gtk_button_new ();
+  select_image = gtk_image_new_from_icon_name ("object-select-symbolic", GTK_ICON_SIZE_MENU);
+  gtk_button_set_image (GTK_BUTTON (priv->select), select_image);
+  gtk_widget_set_valign (priv->select, GTK_ALIGN_CENTER);
+  gtk_style_context_add_class (gtk_widget_get_style_context (priv->select),
+                               "image-button");
+  gtk_header_bar_pack_end (GTK_HEADER_BAR (self), priv->select);
   gtk_widget_set_tooltip_text (priv->select, _("Selection mode"));
 
   g_signal_connect (priv->select,"clicked",
                     G_CALLBACK(on_selection_mode_clicked),self);
 
+  /* Close button */
+  add_close_button (self);
+
   /* Watch for main view changing */
   connect_main_view_handlers (self);
 }
@@ -398,13 +482,17 @@ static void
 populate_bar_for_icon_view(BjbMainToolbar *self)
 {
   BjbMainToolbarPrivate *priv = self->priv;
+  GtkWidget *list_image;
 
   /* Switch to list */
   priv->grid = NULL;
-  priv->list= gd_main_toolbar_add_button(GD_MAIN_TOOLBAR (self),
-                                         "view-list-symbolic",
-                                         NULL,
-                                         FALSE);
+  priv->list = gtk_button_new ();
+  list_image = gtk_image_new_from_icon_name ("view-list-symbolic", GTK_ICON_SIZE_MENU);
+  gtk_button_set_image (GTK_BUTTON (priv->list), list_image);
+  gtk_widget_set_valign (priv->list, GTK_ALIGN_CENTER);
+  gtk_style_context_add_class (gtk_widget_get_style_context (priv->list),
+                               "image-button");
+  gtk_header_bar_pack_end (GTK_HEADER_BAR (self), priv->list);
   gtk_widget_set_tooltip_text (priv->list,
                                _("View notes and collections in a list"));
 
@@ -418,13 +506,17 @@ static void
 populate_bar_for_list_view(BjbMainToolbar *self)
 {
   BjbMainToolbarPrivate *priv = self->priv;
+  GtkWidget *grid_image;
 
   /* Switch to icon view */
   priv->list = NULL;
-  priv->grid = gd_main_toolbar_add_button(GD_MAIN_TOOLBAR (self),
-                                          "view-grid-symbolic",
-                                          NULL,
-                                          FALSE);
+  priv->grid = gtk_button_new ();
+  grid_image = gtk_image_new_from_icon_name ("view-grid-symbolic", GTK_ICON_SIZE_MENU);
+  gtk_button_set_image (GTK_BUTTON (priv->grid), grid_image);
+  gtk_widget_set_valign (priv->grid, GTK_ALIGN_CENTER);
+  gtk_style_context_add_class (gtk_widget_get_style_context (priv->grid),
+                               "image-button");
+  gtk_header_bar_pack_end (GTK_HEADER_BAR (self), priv->grid);
   gtk_widget_set_tooltip_text (priv->grid,
                                _("View notes and collections in a grid"));
 
@@ -465,10 +557,9 @@ static void
 on_note_renamed (BijiNoteObj *note,
                  BjbMainToolbar *self)
 {
-  gd_main_toolbar_set_labels (
-            GD_MAIN_TOOLBAR (self),
-            biji_item_get_title (BIJI_ITEM (note)),
-            NULL);
+  gtk_header_bar_set_title (GTK_HEADER_BAR (self),
+                            biji_item_get_title (BIJI_ITEM (note)));
+  gtk_header_bar_set_subtitle (GTK_HEADER_BAR (self), NULL);
 }
 
 static void
@@ -652,38 +743,51 @@ static void
 populate_bar_for_note_view (BjbMainToolbar *self)
 {
   BjbMainToolbarPrivate *priv = self->priv;
-  GdMainToolbar         *bar = GD_MAIN_TOOLBAR (self);
+  GtkHeaderBar          *bar = GTK_HEADER_BAR (self);
+  BijiCollection        *collection;
   BjbSettings           *settings;
-  GtkWidget             *grid, *notes_icon, *notes_label, *button;
+  GtkWidget             *grid, *notes_icon, *notes_label;
   GdkRGBA                color;
   BijiItem *item;
+  GtkWidget *share_image;
+  GtkWidget *menu_image;
+  gboolean rtl;
 
   priv->note = bjb_window_base_get_note (BJB_WINDOW_BASE (self->priv->window));
   item = BIJI_ITEM (priv->note);
 
+  rtl = (gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL);
+
   if (!priv->note) /* no reason this would happen */
     return;
 
   settings = bjb_app_get_settings (g_application_get_default());
 
+  collection = bjb_controller_get_collection (self->priv->controller);
+
   /* Go to main view basically means closing note */
   grid = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
-  notes_icon = get_icon ("go-previous-symbolic");
+  notes_icon = get_icon (rtl ? "go-previous-rtl-symbolic" : "go-previous-symbolic");
   gtk_box_pack_start (GTK_BOX (grid), notes_icon, TRUE, TRUE, TRUE);
 
-  notes_label = gtk_label_new (_("Notes"));
+  notes_label = gtk_label_new (collection ? biji_item_get_title (BIJI_ITEM (collection)) : _("Notes"));
   gtk_box_pack_start (GTK_BOX (grid), notes_label, TRUE, TRUE, TRUE);
-  button = gtk_button_new ();
-  gtk_container_add (GTK_CONTAINER (button), grid);
-  gd_main_toolbar_add_widget (bar, button, TRUE);
+  priv->back = gtk_button_new ();
+  gtk_widget_set_valign (priv->back, GTK_ALIGN_CENTER);
+  gtk_style_context_add_class (gtk_widget_get_style_context (priv->back),
+                               "text-button");
+  gtk_container_add (GTK_CONTAINER (priv->back), grid);
+  gtk_header_bar_pack_start (bar, priv->back);
  
-  g_signal_connect_swapped (button, "clicked",
+  g_signal_connect_swapped (priv->back, "clicked",
                             G_CALLBACK (just_switch_to_main_view), self);
-  gtk_widget_add_accelerator (button, "activate", self->priv->accel,
+  gtk_widget_add_accelerator (priv->back, "activate", self->priv->accel,
                               GDK_KEY_w, GDK_CONTROL_MASK, GTK_ACCEL_MASK);
 
   /* Note Title */
-  gd_main_toolbar_set_labels (bar, biji_item_get_title (item), NULL);
+
+  gtk_header_bar_set_title (bar, biji_item_get_title (item));
+  gtk_header_bar_set_subtitle (bar, NULL);
 
   self->priv->note_renamed = g_signal_connect (priv->note,"renamed",
                                     G_CALLBACK (on_note_renamed), self);
@@ -701,24 +805,34 @@ populate_bar_for_note_view (BjbMainToolbar *self)
       g_free (default_color);
     }
 
-    button = bjb_color_button_new ();
-    gtk_widget_set_tooltip_text (button, _("Note color"));
-    gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (button), &color);
+    priv->color = bjb_color_button_new ();
+    gtk_widget_set_tooltip_text (priv->color, _("Note color"));
+    gtk_widget_set_valign (priv->color, GTK_ALIGN_CENTER);
+    gtk_style_context_add_class (gtk_widget_get_style_context (priv->color),
+                                 "button");
+    gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (priv->color), &color);
 
-    gd_main_toolbar_add_widget (bar, button, FALSE);
-    gtk_widget_set_size_request (gtk_bin_get_child (GTK_BIN (button)),
+
+    gtk_header_bar_pack_end (bar, priv->color);
+    gtk_widget_set_size_request (gtk_bin_get_child (GTK_BIN (priv->color)),
                                  COLOR_SIZE, COLOR_SIZE);
-    gtk_widget_show (button);
+    gtk_widget_show (priv->color);
 
-    g_signal_connect (button, "color-set",
+    g_signal_connect (priv->color, "color-set",
                       G_CALLBACK (on_color_button_clicked), self);
     priv->note_color_changed = g_signal_connect (priv->note, "color-changed",
-                               G_CALLBACK (on_note_color_changed), button);
+                               G_CALLBACK (on_note_color_changed), priv->color);
   }
 
   /* Sharing */
-  priv->share = gd_main_toolbar_add_button (bar, "send-to-symbolic",
-                                           NULL, FALSE);
+
+  priv->share = gtk_button_new ();
+  share_image = gtk_image_new_from_icon_name ("send-to-symbolic", GTK_ICON_SIZE_MENU);
+  gtk_button_set_image (GTK_BUTTON (priv->share), share_image);
+  gtk_widget_set_valign (priv->share, GTK_ALIGN_CENTER);
+  gtk_style_context_add_class (gtk_widget_get_style_context (priv->share),
+                               "image-button");
+  gtk_header_bar_pack_end (GTK_HEADER_BAR (self), priv->share);
   gtk_widget_set_tooltip_text (priv->share, _("Share note"));
 
   g_signal_connect (priv->share, "clicked",
@@ -732,13 +846,20 @@ populate_bar_for_note_view (BjbMainToolbar *self)
   on_note_content_changed (self);
 
   /* Menu */
-  button = gd_main_toolbar_add_menu (bar,
-                                     "emblem-system-symbolic",
-                                     NULL,
-                                     FALSE);
-  gtk_widget_set_tooltip_text (button, _("More options…"));
 
-  gtk_menu_button_set_popup (GTK_MENU_BUTTON (button),
+  priv->menu = gtk_menu_button_new ();
+  menu_image = gtk_image_new_from_icon_name ("emblem-system-symbolic", GTK_ICON_SIZE_MENU);
+  gtk_button_set_image (GTK_BUTTON (priv->menu), menu_image);
+  gtk_widget_set_valign (priv->menu, GTK_ALIGN_CENTER);
+  gtk_style_context_add_class (gtk_widget_get_style_context (priv->menu),
+                               "image-button");
+  gtk_header_bar_pack_end (bar, priv->menu);
+  gtk_widget_set_tooltip_text (priv->menu, _("More options…"));
+
+  /* Close button */
+  add_close_button (self);
+
+  gtk_menu_button_set_popup (GTK_MENU_BUTTON (priv->menu),
                              bjb_note_menu_new (self));
 }
 
@@ -829,7 +950,8 @@ populate_main_toolbar(BjbMainToolbar *self)
       disconnect_note_handlers (priv);
 
     priv->type = to_be;
-    gd_main_toolbar_clear (GD_MAIN_TOOLBAR (self));
+    bjb_main_toolbar_clear (self);
+    
 
     if (priv->search_handler != 0)
     {
@@ -874,6 +996,7 @@ bjb_main_toolbar_init (BjbMainToolbar *self)
 
   priv->type = BJB_TOOLBAR_0 ;
 
+  priv->back = NULL;
   priv->grid = NULL;
   priv->list = NULL;
   priv->search = NULL;
@@ -883,6 +1006,10 @@ bjb_main_toolbar_init (BjbMainToolbar *self)
 
   priv->accel = NULL;
   priv->note = NULL;
+  priv->back = NULL;
+  priv->color = NULL;
+  priv->menu = NULL;
+  priv->share = NULL;
   priv->note_renamed = 0;
   priv->note_color_changed = 0;
 
@@ -985,7 +1112,6 @@ BjbMainToolbar *
 bjb_main_toolbar_new (BjbMainView *parent,
                       BjbController *controller)
 {
-  /* Since heriting GdMainToolbar, we populate bar _after_ construct */
   BjbMainToolbar *self;
 
   self = BJB_MAIN_TOOLBAR (g_object_new (BJB_TYPE_MAIN_TOOLBAR,
