@@ -62,12 +62,26 @@ struct _BjbSelectionToolbarPrivate
 G_DEFINE_TYPE (BjbSelectionToolbar, bjb_selection_toolbar, GTK_TYPE_TOOLBAR);
 
 
+/*
+ * Color dialog is transient and could damage the display of self
+ * We do not want a modal window since the app may have several
+ * The fix is to hide self untill dialog has run
+ *
+ */
+static void
+hide_self (GtkWidget *self)
+{
+  gtk_widget_set_visible (self, FALSE);
+}
+
+
 static void
 action_color_selected_items (GtkWidget *w, BjbSelectionToolbar *self)
 {
   GList *l, *selection;
   GdkRGBA color = {0,0,0,0};
 
+  gtk_widget_set_visible (GTK_WIDGET (self), TRUE);
   gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER (w), &color);
   selection = bjb_main_view_get_selected_items (self->priv->view);
 
@@ -77,9 +91,11 @@ action_color_selected_items (GtkWidget *w, BjbSelectionToolbar *self)
       biji_note_obj_set_rgba (l->data, &color);
   }
 
+
   g_list_free (selection);
 }
 
+
 static void
 action_tag_selected_items (GtkWidget *w, BjbSelectionToolbar *self)
 {
@@ -137,17 +153,28 @@ bjb_selection_toolbar_set_item_visibility (BjbSelectionToolbar *self)
   priv = self->priv;
   selection = bjb_main_view_get_selected_items (priv->view);
 
-  /* Trash, always,
-   * Color, awlays */
+  /* Trash, always */
   gtk_widget_set_visible (priv->toolbar_trash, TRUE);
 
+
+  /* Color */
+  gtk_widget_set_visible (priv->toolbar_color, FALSE);
+
+
   for (l=selection; l !=NULL; l=l->next)
   {
-    if (BIJI_IS_NOTE_OBJ (l->data))
+    if (!biji_item_has_color (l->data))
+    {
+      gtk_widget_set_visible (priv->toolbar_color, FALSE);
+      break;
+    }
+
+    else if (BIJI_IS_NOTE_OBJ (l->data))
     {
       if (biji_note_obj_get_rgba (BIJI_NOTE_OBJ (l->data), &color))
       {
         gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (priv->toolbar_color), &color);
+        gtk_widget_set_visible (priv->toolbar_color, TRUE);
         break;
       }
     }
@@ -155,13 +182,13 @@ bjb_selection_toolbar_set_item_visibility (BjbSelectionToolbar *self)
 
 
   /* Organize */
-  gtk_widget_set_visible (priv->toolbar_tag, 1);
+  gtk_widget_set_visible (priv->toolbar_tag, TRUE);
 
   for (l=selection; l!=NULL; l=l->next)
   {
-    if (BIJI_IS_COLLECTION (l->data))
+    if (!biji_item_is_collectable (l->data))
     {
-      gtk_widget_set_visible (priv->toolbar_tag, 0);
+      gtk_widget_set_visible (priv->toolbar_tag, FALSE);
       break;
     }
   }
@@ -324,6 +351,9 @@ bjb_selection_toolbar_constructed(GObject *obj)
                     G_CALLBACK(bjb_selection_toolbar_selection_changed),
                     self);
 
+  g_signal_connect_swapped (priv->toolbar_color,"clicked",
+                    G_CALLBACK (hide_self), self);
+
   g_signal_connect (priv->toolbar_color,"color-set",
                     G_CALLBACK (action_color_selected_items), self);
 
