@@ -1,4 +1,5 @@
 
+#include <glib/gi18n.h>
 #include <glib/gprintf.h>
 #include <stdlib.h>
 
@@ -15,7 +16,7 @@
 
 #define BJB_WIDTH 780
 #define BJB_HEIGHT 600
-#define BIJIBEN_MAIN_WIN_TITLE "Bijiben"
+#define BIJIBEN_MAIN_WIN_TITLE N_("Notes")
 
 #define BJB_DEFAULT_FONT "Serif 10"
 
@@ -39,7 +40,7 @@ struct _BjbWindowBasePriv
   BjbSearchToolbar     *search_bar;
 
 
-  GdStack              *stack;
+  GtkStack             *stack;
   BjbWindowViewType     current_view;
   BjbMainView          *view;
   BjbNoteView          *note_view;
@@ -102,7 +103,7 @@ bjb_window_base_constructed (GObject *obj)
   GList *icons = NULL;
   GdkPixbuf *bjb ;
   GError *error = NULL;
-  GdRevealer *revealer;
+  GtkWidget *revealer;
 
   G_OBJECT_CLASS (bjb_window_base_parent_class)->constructed (obj);
 
@@ -111,7 +112,7 @@ bjb_window_base_constructed (GObject *obj)
 
   gtk_window_set_default_size (GTK_WINDOW (self), BJB_WIDTH, BJB_HEIGHT);
   gtk_window_set_position (GTK_WINDOW (self),GTK_WIN_POS_CENTER);
-  gtk_window_set_title (GTK_WINDOW (self), BIJIBEN_MAIN_WIN_TITLE);
+  gtk_window_set_title (GTK_WINDOW (self), _(BIJIBEN_MAIN_WIN_TITLE));
 
   /* Icon for window. TODO - Should be BjbApp */
   icons_path = bijiben_get_bijiben_dir ();
@@ -149,7 +150,7 @@ bjb_window_base_constructed (GObject *obj)
   /* Shared toolbar */
   priv->view = bjb_main_view_new (GTK_WIDGET (obj), priv->controller);
   priv->main_toolbar = bjb_main_toolbar_new (priv->view, priv->controller);
-  gtk_box_pack_start (GTK_BOX (priv->vbox), GTK_WIDGET (priv->main_toolbar), FALSE, FALSE, 0);
+  gtk_window_set_titlebar (GTK_WINDOW (self), GTK_WIDGET (priv->main_toolbar));
 
   /* Search entry toolbar */
   priv->search_bar = bjb_search_toolbar_new (GTK_WIDGET (obj), priv->controller);
@@ -157,19 +158,19 @@ bjb_window_base_constructed (GObject *obj)
   gtk_box_pack_start (GTK_BOX (priv->vbox), GTK_WIDGET (revealer), FALSE, FALSE, 0);
 
   /* UI : stack for different views */
-  priv->stack = GD_STACK (gd_stack_new ());
+  priv->stack = GTK_STACK (gtk_stack_new ());
   gtk_box_pack_start (GTK_BOX (priv->vbox), GTK_WIDGET (priv->stack), TRUE, TRUE, 0);
 
   priv->spinner = gtk_spinner_new ();
-  gd_stack_add_named (priv->stack, priv->spinner, "spinner");
-  gd_stack_set_visible_child_name (priv->stack, "spinner");
+  gtk_stack_add_named (priv->stack, priv->spinner, "spinner");
+  gtk_stack_set_visible_child_name (priv->stack, "spinner");
   gtk_widget_show (priv->spinner);
   gtk_spinner_start (GTK_SPINNER (priv->spinner));
 
   priv->no_note = bjb_empty_results_box_new ();
-  gd_stack_add_named (priv->stack, priv->no_note, "empty");
+  gtk_stack_add_named (priv->stack, priv->no_note, "empty");
 
-  gd_stack_add_named (priv->stack, GTK_WIDGET (priv->view), "main-view");
+  gtk_stack_add_named (priv->stack, GTK_WIDGET (priv->view), "main-view");
 
   g_signal_connect (
     GTK_WIDGET (self), "destroy", G_CALLBACK (bjb_window_base_destroy), self);
@@ -220,7 +221,6 @@ bjb_window_base_new(void)
 {
   return g_object_new (BJB_TYPE_WINDOW_BASE,
                        "application", g_application_get_default(),
-                       "hide-titlebar-when-maximized", TRUE,
                        NULL);
 }
 
@@ -274,12 +274,12 @@ bjb_window_base_switch_to (BjbWindowBase *bwb, BjbWindowViewType type)
     case BJB_WINDOW_BASE_MAIN_VIEW:
       bjb_search_toolbar_connect (priv->search_bar);
       bjb_main_view_connect_signals (priv->view);
-      gd_stack_set_visible_child_name (priv->stack, "main-view");
+      gtk_stack_set_visible_child_name (priv->stack, "main-view");
       break;
 
 
     case BJB_WINDOW_BASE_SPINNER_VIEW:
-      gd_stack_set_visible_child_name (priv->stack, "spinner");
+      gtk_stack_set_visible_child_name (priv->stack, "spinner");
       break;
 
 
@@ -287,7 +287,7 @@ bjb_window_base_switch_to (BjbWindowBase *bwb, BjbWindowViewType type)
       bjb_empty_results_box_set_type (BJB_EMPTY_RESULTS_BOX (priv->no_note),
                                       BJB_EMPTY_RESULTS_NO_NOTE);
       gtk_widget_show (priv->no_note);
-      gd_stack_set_visible_child_name (priv->stack, "empty");
+      gtk_stack_set_visible_child_name (priv->stack, "empty");
       break;
 
 
@@ -295,13 +295,13 @@ bjb_window_base_switch_to (BjbWindowBase *bwb, BjbWindowViewType type)
       bjb_empty_results_box_set_type (BJB_EMPTY_RESULTS_BOX (priv->no_note),
                                       BJB_EMPTY_RESULTS_NO_RESULTS);
       gtk_widget_show (priv->no_note);
-      gd_stack_set_visible_child_name (priv->stack, "empty");
+      gtk_stack_set_visible_child_name (priv->stack, "empty");
       break;
 
 
     case BJB_WINDOW_BASE_NOTE_VIEW:
       gtk_widget_show_all (GTK_WIDGET (priv->note_overlay));
-      gd_stack_set_visible_child_name (priv->stack, "note-view");
+      gtk_stack_set_visible_child_name (priv->stack, "note-view");
       break;
 
 
@@ -325,7 +325,7 @@ bjb_window_base_switch_to_note (BjbWindowBase *bwb, BijiNoteObj *note)
   priv->note = note;
   priv->note_overlay = gtk_overlay_new ();
 
-  gd_stack_add_named (priv->stack, priv->note_overlay, "note-view");
+  gtk_stack_add_named (priv->stack, priv->note_overlay, "note-view");
   priv->note_view = bjb_note_view_new (w, priv->note_overlay, note);
 
   g_object_add_weak_pointer (G_OBJECT (priv->note_view),
